==> apache-shardingsphere-5.5.2-src.zip: apache-shardingsphere-5.5.2-src-release/infra/common/src/main/java/org/apache/shardingsphere/infra/exception/kernel/data/UnsupportedDataTypeConversionException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.infra.exception.kernel.data;

import org.apache.shardingsphere.infra.exception.core.external.sql.type.kernel.category.DataSQLException;
import org.apache.shardingsphere.infra.exception.core.external.sql.sqlstate.XOpenSQLState;

import java.util.Objects;

/**
 * Unsupported data type conversion exception.
 */
public final class UnsupportedDataTypeConversionException extends DataSQLException {
    
    private static final long serialVersionUID = 4808672149254705863L;
    
    public UnsupportedDataTypeConversionException(final Class<?> convertType, final Object value) {
        super(XOpenSQLState.INVALID_DATA_TYPE, 0, "Unsupported conversion data type '%s' for value '%s'.", convertType.getName(), Objects.toString(value));
    }
}

==> apache-shardingsphere-5.5.3-src.zip: apache-shardingsphere-5.5.3-src-release/infra/common/src/main/java/org/apache/shardingsphere/infra/exception/kernel/data/UnsupportedDataTypeConversionException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.infra.exception.kernel.data;

import org.apache.shardingsphere.infra.exception.external.sql.sqlstate.XOpenSQLState;
import org.apache.shardingsphere.infra.exception.external.sql.type.kernel.category.DataSQLException;

import java.util.Objects;

/**
 * Unsupported data type conversion exception.
 */
public final class UnsupportedDataTypeConversionException extends DataSQLException {
    
    private static final long serialVersionUID = 4808672149254705863L;
    
    public UnsupportedDataTypeConversionException(final Class<?> convertType, final Object value) {
        super(XOpenSQLState.INVALID_DATA_TYPE, 0, "Unsupported conversion data type '%s' for value '%s'.", convertType.getName(), Objects.toString(value));
    }
}
